@@ -7,7 +7,7 @@ login <- function(connection, verbose=FALSE){
                          body=list("username"=connection@username,
                                    "password"=connection@password,
                                    "loginMode"=connection@login_mode),
-                         encode='json')
+                         encode="json")
   if(verbose){
     print(response$url)
   }
@@ -19,7 +19,7 @@ login <- function(connection, verbose=FALSE){
 logout <- function(connection, verbose=FALSE){
   response <- httr::POST(url=paste0(connection@base_url, "/auth/logout"),
                          add_headers("X-MSTR-AuthToken"=connection@auth_token),
-                         encode='json')
+                         encode="json")
   if(verbose){
     print(response$url)
   }
@@ -29,8 +29,8 @@ logout <- function(connection, verbose=FALSE){
 
 # Check that the user's session is still active, and renews the authentication token on the server side
 sessions <- function(connection, verbose=FALSE){
-  response <- httr::PUT(url=paste0(connection@base_url, '/sessions'),
-                        add_headers('X-MSTR-AuthToken'=connection@auth_token),
+  response <- httr::PUT(url=paste0(connection@base_url, "/sessions"),
+                        add_headers("X-MSTR-AuthToken"=connection@auth_token),
                         set_cookies(connection@cookies))
   if(verbose){
     print(response$url)
